@@ -5,7 +5,7 @@ import cv2
 import numpy as np
 import pyautogui
 
-from smb3_eh_manip.settings import config
+from smb3_eh_manip.settings import config, get_config_region
 from smb3_eh_manip.video_player import VideoPlayer
 
 CLEAR_SIGHTING_DURATION_SECONDS = 10
@@ -18,9 +18,11 @@ class OpencvComputer:
         player_video_path,
         start_frame_image_path,
         video_offset_frames=0,
+        start_frame_image_region=None,
     ):
         self.player_window_title = player_window_title
         self.start_frame_image_path = start_frame_image_path
+        self.start_frame_image_region = start_frame_image_region
         self.show_capture_video = config.getboolean("app", "show_capture_video")
         self.autoreset = config.getboolean("app", "autoreset")
         self.enable_fceux_tas_start = config.getboolean("app", "enable_fceux_tas_start")
@@ -54,6 +56,10 @@ class OpencvComputer:
             )
         if self.enable_video_player:
             self.video_player = VideoPlayer(player_video_path, video_offset_frames)
+        self.reset_image_region = get_config_region("app", "reset_image_region")
+        self.end_stage_clear_text_region = get_config_region(
+            "app", "end_stage_clear_text_region"
+        )
 
     def tick(self):
         self.current_time = time.time()
@@ -70,7 +76,9 @@ class OpencvComputer:
             > CLEAR_SIGHTING_DURATION_SECONDS
             and list(
                 OpencvComputer.locate_all_opencv(
-                    self.end_stage_clear_text_template, frame
+                    self.end_stage_clear_text_template,
+                    frame,
+                    region=self.end_stage_clear_text_region,
                 )
             )
         ):
@@ -81,7 +89,11 @@ class OpencvComputer:
         if (
             self.autoreset
             and self.playing
-            and list(OpencvComputer.locate_all_opencv(self.reset_template, frame))
+            and list(
+                OpencvComputer.locate_all_opencv(
+                    self.reset_template, frame, region=self.reset_image_region
+                )
+            )
         ):
             self.playing = False
             self.start_time = -1
@@ -97,7 +109,11 @@ class OpencvComputer:
                 #    pyautogui.press("backslash")
             logging.info(f"Detected reset")
         if not self.playing:
-            results = list(OpencvComputer.locate_all_opencv(self.template, frame))
+            results = list(
+                OpencvComputer.locate_all_opencv(
+                    self.template, frame, region=self.start_frame_image_region
+                )
+            )
             if self.show_capture_video:
                 for x, y, needleWidth, needleHeight in results:
                     top_left = (x, y)
@@ -128,19 +144,11 @@ class OpencvComputer:
         needleImage,
         haystackImage,
         limit=10000,
-        region=None,
-        step=1,
+        region=None,  # [x, y, width, height]
         confidence=float(config.get("app", "confidence")),
     ):
         """
-        TODO - rewrite this
-            faster but more memory-intensive than pure python
-            step 2 skips every other row and column = ~3x faster but prone to miss;
-                to compensate, the algorithm automatically reduces the confidence
-                threshold by 5% (which helps but will not avoid all misses).
-            limitations:
-            - OpenCV 3.x & python 3.x not tested
-            - RGBA images are treated as RBG (ignores alpha channel)
+        RGBA images are treated as RBG (ignores alpha channel)
         """
 
         confidence = float(confidence)
@@ -162,13 +170,6 @@ class OpencvComputer:
                 "needle dimension(s) exceed the haystack image or region dimensions"
             )
 
-        if step == 2:
-            confidence *= 0.95
-            needleImage = needleImage[::step, ::step]
-            haystackImage = haystackImage[::step, ::step]
-        else:
-            step = 1
-
         # get all matches at once, credit: https://stackoverflow.com/questions/7670112/finding-a-subimage-inside-a-numpy-image/9253805#9253805
         result = cv2.matchTemplate(haystackImage, needleImage, cv2.TM_CCOEFF_NORMED)
         match_indices = np.arange(result.size)[(result > confidence).flatten()]
@@ -178,7 +179,7 @@ class OpencvComputer:
             return
 
         # use a generator for API consistency:
-        matchx = matches[1] * step + region[0]  # vectorized
-        matchy = matches[0] * step + region[1]
+        matchx = matches[1] + region[0]  # vectorized
+        matchy = matches[0] + region[1]
         for x, y in zip(matchx, matchy):
             yield (x, y, needleWidth, needleHeight)
