@@ -1,4 +1,3 @@
-from smb3_eh_manip.video_player import VideoPlayer
 from smb3_eh_manip.computers.opencv_computer import OpencvComputer
 from smb3_eh_manip.settings import config
 
@@ -6,10 +5,7 @@ from smb3_eh_manip.settings import config
 class TwoOneComputer(OpencvComputer):
     def __init__(self):
         super().__init__(
-            VideoPlayer(
-                "video",
-                config.get("app", "two_one_video_path"),
-                config.getint("app", "latency_frames"),
-            ),
+            "twoonevideo",
+            config.get("app", "two_one_video_path"),
             config.get("app", "two_one_start_frame_image_path"),
         )
\ No newline at end of file
